@@ -275,9 +275,9 @@ if __name__ == "__main__":
 
         imp_tester.output_results(out_data_path)
 
-    if os.getenv("imp_do_screeplot_tests", "False").lower() == "true":
+    if os.getenv("imp_do_nmf_with_missings", "False").lower() == "true":
 
-        nb_clusters = 10
+        nb_clusters = 1
         min_corr = 0.9
         max_corr = 0.10
         h_avg_csize = 20
@@ -285,6 +285,9 @@ if __name__ == "__main__":
         eps = 0
         random_norms = True
         censor_rate = 0.0
+        censor_indices_list = [[],
+                               [[0, 0]],
+                               [[0, 0], [1, 2]]]
         gen_m, gen_w, gen_h, gen_noise = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
                                                                          min_intra_corr=min_corr,
                                                                          max_inter_corr=max_corr,
@@ -292,29 +295,54 @@ if __name__ == "__main__":
                                                                          w_avg_clust_size=w_avg_csize,
                                                                          epsilon=eps,
                                                                          random_norms=random_norms)
-        utl.censor_data(mat=gen_m, p=censor_rate, inplace=True)
-        rnstr = "RandNorms" if random_norms else "ConstNorms"
-        wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
-                  f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_rate}.csv"
-        gen_m.to_csv(res_path / "random_nmf" / wh_name,
-                     float_format="%.4f")
-        df_scree_plot = nmf.generate_scree_plot(gen_m, ncmin=6, ncmax=12)
-        df_scree_plot.to_csv(res_path / f"{wh_name}_screeplot.csv")
-        censor_rate = 0.01
+        for censor_indices in censor_indices_list:
+
+            utl.censor_data(mat=gen_m, censored_indices=censor_indices, inplace=True)
+            rnstr = "RandNorms" if random_norms else "ConstNorms"
+            wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
+                      f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_indices}.csv"
+            gen_m.to_csv(res_path / "random_nmf" / wh_name,
+                         float_format="%.4f")
+            gen_m_nmf = nmf.NmfModel(mat=gen_m, ncomp=nb_clusters)
+            gen_m_nmf.test_model()
+            nmf_w = gen_m_nmf.get_w()
+            nmf_h = gen_m_nmf.get_h()
+            nmf_w.to_csv(res_path / "random_nmf" / f"W_{wh_name}",
+                         float_format="%.4f")
+            nmf_h.to_csv(res_path / "random_nmf" / f"H_{wh_name}",
+                         float_format="%.4f")
+            df_scree_plot = nmf.generate_scree_plot(gen_m, ncmin=1, ncmax=10)
+            df_scree_plot.to_csv(res_path / f"{wh_name}_screeplot.csv")
+
+    if os.getenv("imp_do_screeplot_tests", "False").lower() == "true":
+
+        nb_clusters = 12
+        nb_clusters = 1
+        min_corr = 0.9
+        max_corr = 0.10
+        h_avg_csize = 40
+        w_avg_csize = 30
+        eps = 0
+        random_norms = True
+        censor_rate = 0.0
+
         read_wh_mat = (os.getenv("imp_read_whmat", "True").lower() == "true")
         rnstr = "RandNorms" if random_norms else "ConstNorms"
 
-        censor_rates = [0.0]
+        censor_rates = [0.0, 0.01, 0.05, 0.10]
         for censor_rate in censor_rates:
 
             if read_wh_mat:
                 fixed_mat_name = os.getenv("imp_wh_matname")
+                fixed_w_name = os.getenv("imp_w_matname")
+                fixed_h_name = os.getenv("imp_h_matname")
                 rad_name = fixed_mat_name.split(".csv")[0]
                 wh_name = f"{rad_name}_mis{censor_rate}.csv"
                 # wh_name = "M_nc10_corrmin0.9_corrmax0.1_noise0_RandNorms_mis0.0.csv"
                 gen_M = pd.read_csv(data_path / fixed_mat_name, index_col=0)
-                gen_w = pd.read_csv(data_path / f"w_{fixed_mat_name}", index_col=0)
-                gen_h = pd.read_csv(data_path / f"h_{fixed_mat_name}", index_col=0)
+                gen_w = pd.read_csv(data_path / fixed_w_name, index_col=0)
+                gen_h = pd.read_csv(data_path / fixed_h_name, index_col=0)
+                # gen_M = gen_w @ gen_h
             else:
                 wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr, 2)}_" \
                           f"corrmax{round(max_corr, 2)}_noise{round(eps, 2)}_{rnstr}_mis{censor_rate}.csv"
